@@ -15,6 +15,8 @@
  *  WWW at http://www.gnu.org/copyleft/gpl.html).
  */
 
+void Rprintf(const char *, ...);
+
 #include "macro.h"
 #include "options.h"
 #include "output.h"
@@ -1069,36 +1071,36 @@ print_macro_definition(char *name, int args) {
   else {
     macro = MacroHashLookup(name, args);
     if (macro == NULL) {
-      printf("Macro %s(%d) not defined.\n", name, args);
+      Rprintf("Macro %s(%d) not defined.\n", name, args);
     }
     else {
-      printf("/%s[", name);
+      Rprintf("/%s[", name);
       for (i = 0; i < args; i++) {
 	if (macro->argnames[i] != NULL) {
-	  printf("%s", macro->argnames[i]);
+	  Rprintf("?%s?", macro->argnames[i]);
 	}
 	else {
-	  printf("%d", i);
+	  Rprintf("?%d?", i);
 	}
-	if (i < (args-1)) printf(", ");
+	if (i < (args-1)) Rprintf(", ");
       }
-      printf("] = \n");
+      Rprintf("] = \n");
       for (seg = macro->replacement; seg != NULL; seg = seg->next) {
 	if (seg->arg >= 0) {
 	  i = seg->arg;
 	  if (macro->argnames[i] != NULL) {
-	    printf("%s", macro->argnames[i]);
+	    Rprintf("?%s?", macro->argnames[i]);
 	  }
 	  else {
-	    printf("%d", i);
+	    Rprintf("?%d?", i);
 	  }
 	}
 	else if (seg->string != NULL)
-	  printf("%s", seg->string);
+	  Rprintf("%s", seg->string);
 	else 
-	  printf("$$");
+	  Rprintf("?$$?");
       }
-      printf("\n");
+      Rprintf("\n");
     }
   }
 }
