@@ -25,6 +25,8 @@
 /* with the usual precedence rules.                                   */
 /* ****************************************************************** */
 
+void Rprintf(const char *, ...);
+
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
@@ -248,7 +250,7 @@ Lexical LEX(void)
   if (isalpha(Ch) || Ch == '_' || Ch == '$') {
     for (LastW = ChP; isalnum(Ch) || Ch == '_' || Ch == '$'; ChP++) {
       if (ChP - ChArr == MAX_CHAR) {
-        printf("Out of character space.\n");
+       Rprintf("Out of character space.\n");
         exit(1);
       }
       *ChP = Ch;
@@ -257,7 +259,7 @@ Lexical LEX(void)
     if (Ch != EOF) 
       UNGET(Ch);
     if (ChP - ChArr == MAX_CHAR) {
-      printf("Out of character space.\n");
+     Rprintf("Out of character space.\n");
       exit(1);
     }
     *ChP++ = '\0';
@@ -267,18 +269,18 @@ Lexical LEX(void)
     Ch = GET();
     for (LastW = ChP; Ch != '"' && Ch != EOF; ChP++) {
       if (ChP - ChArr == MAX_CHAR) {
-        printf("Out of character space.\n");
+       Rprintf("Out of character space.\n");
         exit(1);
       }
       *ChP = Ch;
       Ch = GET();
     }
     if (Ch == EOF) {
-      printf("Missing closing \".\n");
+     Rprintf("Missing closing \".\n");
       exit(1);
     }
     if (ChP - ChArr == MAX_CHAR) {
-      printf("Out of character space.\n");
+     Rprintf("Out of character space.\n");
       exit(1);
     }
     *ChP++ = '\0';
@@ -956,19 +958,19 @@ WriteStates(void)
       if (SP->Class != Classes) 
         continue;
       Classes++;
-      printf("s%d =", SP->Class);
+     Rprintf("s%d =", SP->Class);
       if (SP->Empty) 
         {
-          printf(" fin");
+         Rprintf(" fin");
           if (SP->Shifts > 0) 
-            printf(" |");
+            Rprintf(" |");
         }
       for (Sh = 0; Sh < SP->Shifts; Sh++) 
         {
           C = SP->ShList[Sh].RHS;
           if (Sh > 0) 
-            printf(" |");
-          printf(" %s s%d", SP->ShList[Sh].LHS->Name, STab[C].Class);
+            Rprintf(" |");
+          Rprintf(" %s s%d", SP->ShList[Sh].LHS->Name, STab[C].Class);
         }
       putchar('\n');
     }
@@ -1011,18 +1013,18 @@ show_complete_dfa(DFA dfa)
   int i, j;
 
   for (i = 0; i < dfa.Max_States; i++) {
-    printf("s%d", i);
+    Rprintf("s%d", i);
     if (dfa.Final[i])
-      printf("(final)");
+      Rprintf("(final)");
     else
       putchar('\t');
     for (j = 0; j < dfa.Max_Input; j++)
       {
-        printf("\t%d -> ", j);
+        Rprintf("\t%d -> ", j);
         if (dfa.TransTable[i][j] == dfa.E_State)
-          printf("E\t");
+          Rprintf("E\t");
         else
-          printf("s%d,",dfa.TransTable[i][j]);
+          Rprintf("s%d,",dfa.TransTable[i][j]);
       }
     putchar('\n');
   }
