@@ -5,7 +5,7 @@ testthat::context("attribute_size")
 test_that(
   "attribute size s-attribute places",
   {
-    N <- cwb_attribute_size(
+    N <- cl_attribute_size(
       corpus = "REUTERS",
       attribute = "places",
       attribute_type = "s",
@@ -18,7 +18,7 @@ test_that(
 test_that(
   "attribute size p-attribute word",
   {
-    N <- cwb_attribute_size(
+    N <- cl_attribute_size(
       corpus = "REUTERS",
       attribute = "word",
       attribute_type = "p",
